Simple tests
------------

Ensure your device works with these simple tests.

.. literalinclude:: ../examples/focaltouch_print_touches.py
    :caption: examples/focaltouch_print_touches.py
    :linenos:

.. literalinclude:: ../examples/focaltouch_paint_simpletest.py
    :caption: examples/focaltouch_paint_simpletest.py
    :linenos:

.. literalinclude:: ../examples/focaltouch_print_touches_with_irq.py
    :caption: examples/focaltouch_print_touches_with_irq.py
    :linenos:

Demos
-----

These demos are a bit more complex.

.. literalinclude:: ../examples/focaltouch_paint_rgb666.py
    :caption: examples/focaltouch_paint_rgb666.py
    :linenos:
